@@ -1,7 +1,10 @@
 import os
 
 import pyximport
-from typeguard.importhook import install_import_hook
+try:
+    from typeguard import install_import_hook
+except ImportError:
+    from typeguard.importhook import install_import_hook
 
 pyximport.install(language_level=3)
 
